starcluster.optcomplete.ListCompleter

Package starcluster :: Module optcomplete :: Class ListCompleter |
[hide private]
[frames] | no frames]

# Class ListCompleter

source code

Completes by filtering using a fixed list of strings.

Instance Methods | [hide private]
__init__(self, stringlist) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
__call__(self, pwd, line, point, prefix, suffix) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, stringlist) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)